@@ -30,3 +30,14 @@ def upgrade11(context):
     jstool.cookResources()
     csstool = getToolByName(context, 'portal_css')
     csstool.cookResources()
+
+def upgrade12(context):
+    portal_quickinstaller = getToolByName(context, 'portal_quickinstaller')
+    portal_setup = getToolByName(context, 'portal_setup')
+
+    portal_setup.runAllImportStepsFromProfile('profile-Solgema.fullcalendar:upgrade12', purge_old=False)
+
+    jstool = getToolByName(context, 'portal_javascripts')
+    jstool.cookResources()
+    csstool = getToolByName(context, 'portal_css')
+    csstool.cookResources()
